@@ -1,6 +1,8 @@
 from sqlalchemy import Column
 from sqlalchemy import Integer
 from sqlalchemy import String
+from sqlalchemy import DateTime
+from sqlalchemy.sql import func
 from sqlalchemy.dialects.mysql import TINYINT
 from marshmallow import fields
 from marshmallow import Schema
@@ -16,6 +18,9 @@ class User(Base):
     email = Column(String(30), nullable=False, unique=True)
     password = Column(String(100), nullable=False)
     active = Column(TINYINT, nullable=False, server_default='0')
+    registration_date = Column(DateTime, nullable=False, server_default=func.now())
+    activation_date = Column(DateTime, nullable=True)
+    updated_date = Column(DateTime, nullable=True, onupdate=func.now())
 
 
 class UserSchema(Schema):
